@@ -3,13 +3,16 @@ from __future__ import unicode_literals, print_function
 import warnings
 from datetime import datetime, timedelta
 import six
-from lazy import lazy
 from abc import ABCMeta, abstractmethod, abstractproperty
 from werkzeug.datastructures import CallbackDict
 import flask
 from flask.signals import Namespace
 from flask_dance.consumer.storage.session import SessionStorage
-from flask_dance.utils import getattrd, timestamp_from_datetime
+from flask_dance.utils import (
+    getattrd,
+    timestamp_from_datetime,
+    invalidate_cached_property,
+)
 
 
 _signals = Namespace()
@@ -32,7 +35,6 @@ class BaseOAuthConsumerBlueprint(six.with_metaclass(ABCMeta, flask.Blueprint)):
         root_path=None,
         login_url=None,
         authorized_url=None,
-        backend=None,
         storage=None,
     ):
 
@@ -65,14 +67,6 @@ class BaseOAuthConsumerBlueprint(six.with_metaclass(ABCMeta, flask.Blueprint)):
             view_func=self.authorized,
         )
 
-        if backend is not None:
-            warnings.warn(
-                "The `backend` parameter is deprecated. "
-                "Please use the `storage` parameter instead.",
-                DeprecationWarning,
-            )
-            storage = backend
-
         if storage is None:
             self.storage = SessionStorage()
         elif callable(storage):
@@ -82,7 +76,7 @@ class BaseOAuthConsumerBlueprint(six.with_metaclass(ABCMeta, flask.Blueprint)):
 
         self.logged_in_funcs = []
         self.from_config = {}
-        invalidate_token = lambda d: lazy.invalidate(self.session, "token")
+        invalidate_token = lambda d: invalidate_cached_property(self.session, "token")
         self.config = CallbackDict(on_update=invalidate_token)
         self.before_app_request(self.load_config)
 
@@ -132,30 +126,12 @@ class BaseOAuthConsumerBlueprint(six.with_metaclass(ABCMeta, flask.Blueprint)):
             expires_at = datetime.utcnow() + delta
             _token["expires_at"] = timestamp_from_datetime(expires_at)
         self.storage.set(self, _token)
-        lazy.invalidate(self.session, "token")
+        invalidate_cached_property(self.session, "token")
 
     @token.deleter
     def token(self):
         self.storage.delete(self)
-        lazy.invalidate(self.session, "token")
-
-    @property
-    def backend(self):
-        warnings.warn(
-            "The `backend` property is deprecated. "
-            "Please use the `storage` property instead.",
-            DeprecationWarning,
-        )
-        return self.storage
-
-    @backend.setter
-    def backend(self, value):
-        warnings.warn(
-            "The `backend` property is deprecated. "
-            "Please use the `storage` property instead.",
-            DeprecationWarning,
-        )
-        self.storage = value
+        invalidate_cached_property(self.session, "token")
 
     @abstractproperty
     def session(self):
