@@ -25,7 +25,6 @@ def make_google_blueprint(
     login_url=None,
     authorized_url=None,
     session_class=None,
-    backend=None,
     storage=None,
     hosted_domain=None,
 ):
@@ -33,7 +32,8 @@ def make_google_blueprint(
     Make a blueprint for authenticating with Google using OAuth 2. This requires
     a client ID and client secret from Google. You should either pass them to
     this constructor, or make sure that your Flask application config defines
-    them, using the variables GOOGLE_OAUTH_CLIENT_ID and GOOGLE_OAUTH_CLIENT_SECRET.
+    them, using the variables :envvar:`GOOGLE_OAUTH_CLIENT_ID` and
+    :envvar:`GOOGLE_OAUTH_CLIENT_SECRET`.
 
     Args:
         client_id (str): The client ID for your application on Google
@@ -134,7 +134,6 @@ def make_google_blueprint(
         authorized_url=authorized_url,
         authorization_url_params=authorization_url_params,
         session_class=session_class,
-        backend=backend,
         storage=storage,
     )
     google_bp.from_config["client_id"] = "GOOGLE_OAUTH_CLIENT_ID"
